@@ -36,9 +36,11 @@ public:
 public slots:
     /*$PUBLIC_SLOTS$*/
     virtual void slotNetworkSetupClicked();
-    virtual void slotDetailAndLogSetupClicked();
+    virtual void slotDetailSetupClicked();
+    virtual void slotLogSetupClicked();
     virtual void slotClickableUrlClicked();
     virtual void slotUnlockPasswordSetup();
+    virtual void slotHideSetupClicked();
     virtual void slotOkClicked();
     virtual void slotCancelClicked();
     virtual void slotApplyClicked();
