@@ -22,6 +22,7 @@
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kwin.h>
+#include <kdebug.h>
 #include <klistview.h>
 #include <qtextcodec.h>
 #include <qlabel.h>
@@ -38,6 +39,26 @@
 
 static KIpMsgNotify *notity = NULL;
 
+/**
+ * 通知イベント開始前イベント
+ * ・GUIスレッドのロック
+ */
+void
+KIpMsgEvent::EventBefore(){
+	if ( kapp != NULL ){
+		kapp->lock();
+	}
+}
+/**
+ * 通知イベント終了後イベント
+ * ・GUIスレッドのアンロック
+ */
+void
+KIpMsgEvent::EventAfter(){
+	if ( kapp != NULL ){
+		kapp->unlock();
+	}
+}
 /**
  * ホストリストリフレッシュ後イベント
  * ・全ての送信ウインドウのホストリストを更新する
@@ -78,9 +99,6 @@ KIpMsgEvent::GetHostListRetryError(){
  */
 bool
 KIpMsgEvent::RecieveAfter( RecievedMessage& msg ){
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	if ( !kipmsgWidget::isRecievedOnNonePopup() ) {
 		ShowRecieveMsg( msg );
 	} else {
@@ -95,9 +113,6 @@ KIpMsgEvent::RecieveAfter( RecievedMessage& msg ){
 		hiddenMessages.push_back( msg );
 	}
 	kipmsgWidget::playSound();
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 	return true;
 }
 
@@ -163,9 +178,6 @@ KIpMsgEvent::SendRetryError( SentMessage& msg ){
  */
 void
 KIpMsgEvent::OpenAfter( SentMessage& msg ){
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	IpMessengerAgent *IpMsgAgent = IpMessengerAgent::GetInstance();
 	if ( msg.IsSecret() && msg.IsConfirmed() && !msg.IsConfirmAnswered() ) {
 		QString encode("");
@@ -178,7 +190,7 @@ KIpMsgEvent::OpenAfter( SentMessage& msg ){
 		QString IpAddr = msg.Host().IpAddress().c_str();
 		QString UserName = msg.Host().UserName().c_str();
 		for( QStringList::iterator ite = encodings.begin(); ite != encodings.end(); ite++ ){
-			QStringList fields = QStringList::split( ":", *ite );
+			QStringList fields = QStringList::split( "|", *ite );
 			if ( IpAddr == fields[0] && UserName == fields[1] ) {
 				encode = fields[2];
 				break;
@@ -197,9 +209,6 @@ KIpMsgEvent::OpenAfter( SentMessage& msg ){
 		}
 		confirmDialogs.append(opendlg);
 	}
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 }
 
 /**
@@ -267,9 +276,6 @@ KIpMsgEvent::DownloadProcessing( RecievedMessage& /*msg*/, AttachFile& file, Dow
  */
 void
 KIpMsgEvent::DownloadEnd( RecievedMessage& msg, AttachFile& file, DownloadInfo& info, void *data ){
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	RecieveDialog *recvDlg = static_cast<RecieveDialog *>(data);
 	if ( recvDlg->isOpenSaveDialog() ){
 		DownloadCompleteDialog *dlg = new DownloadCompleteDialog(recvDlg, 0, TRUE);
@@ -278,9 +284,6 @@ KIpMsgEvent::DownloadEnd( RecievedMessage& msg, AttachFile& file, DownloadInfo&
 		delete dlg;
 	}
 	msg.Files().erase( file );
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 }
 
 /**
@@ -313,16 +316,10 @@ KIpMsgEvent::EntryAfter( HostListItem& host ){
 	if ( host.IsLocalHost() || !KIpMsgSettings::notifyOnLoginLogoutAbsence() ) {
 		return;
 	}
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	GetHostEncodingFromConfig( host );
 	notity = createNotifyWindow();
 	notity->addLoginMessage( host );
 	notity->show();
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 }
 
 /**
@@ -335,16 +332,10 @@ KIpMsgEvent::ExitAfter( HostListItem& host ){
 	if ( host.IsLocalHost() || !KIpMsgSettings::notifyOnLoginLogoutAbsence() ) {
 		return;
 	}
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	GetHostEncodingFromConfig( host );
 	notity = createNotifyWindow();
 	notity->addLogoutMessage( host );
 	notity->show();
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 }
 
 /**
@@ -358,16 +349,10 @@ KIpMsgEvent::AbsenceModeChangeAfter( HostListItem& host )
 	if ( host.IsLocalHost() || !KIpMsgSettings::notifyOnLoginLogoutAbsence() ) {
 		return;
 	}
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	GetHostEncodingFromConfig( host );
 	notity = createNotifyWindow();
 	notity->addAbsenceModeChangeMessage( host );
 	notity->show();
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 }
 
 /**
@@ -422,10 +407,10 @@ void KIpMsgEvent::AbsenceDetailRecieveAfter( HostListItem &host, string absenceD
 void 
 KIpMsgEvent::GetHostEncodingFromConfig( HostListItem &host )
 {
-	host.setEncodingName( "" );
+	host.setEncodingName( "Shift-JIS" );
 	QStringList encodings = KIpMsgSettings::encodingSettings();
 	for( QStringList::iterator ite = encodings.begin(); ite != encodings.end(); ite++ ){
-		QStringList fields = QStringList::split( ":", *ite );
+		QStringList fields = QStringList::split( "|", *ite );
 		if ( QString( host.IpAddress().c_str() ) == fields[0] && 
 			QString( host.UserName().c_str() ) == fields[1] ) {
 			host.setEncodingName( string( fields[2].data() ) );
@@ -592,9 +577,6 @@ KIpMsgEvent::TimerEvent(){
  */
 void
 KIpMsgEvent::ShowRecieveMsg( RecievedMessage& msg ){
-	if ( kapp != NULL ){
-		kapp->lock();
-	}
 	RecieveDialog *recv = new RecieveDialog(msg,0,0,0);
 	recv->setDownloadFiles();
 	recv->show();
@@ -603,9 +585,6 @@ KIpMsgEvent::ShowRecieveMsg( RecievedMessage& msg ){
 	}
 	KWin::activateWindow( recv->winId() );
 	recieveDialogs.append( recv );
-	if ( kapp != NULL ){
-		kapp->unlock();
-	}
 //	kipmsgWidget::playSound();
 }
 
